Skip to contents

Filertting out based on numner of nunique occurences

Usage

filtering_out_data(data, threshold)

Arguments

data

A data.frame or similar.

threshold

an integer

Value

  • data_filtered data.frame same as data filtered out according to threshold

  • validation_rules a set of validation rules defined with validate::validator().