This module allow to import data into the application, to map input's columns to variable of interest for the simulation and to validate that all is in order to proceed.
Usage
data_full_ui(id)
data_full_server(id, main_session = shiny::getDefaultReactiveDomain())Value
UI: HTML tags that can be included in the UI part of the application.
Server: a
shiny::reactive()function returning adata.frame.