Data source Module
Value
UI: HTML tags that can be included in the UI part of the application.
Server: a
shiny::reactive()function returning adata.frame.
Data source Module
UI: HTML tags that can be included in the UI part of the application.
Server: a shiny::reactive() function returning a data.frame.