Skip to contents

Data filtering out Module

Data Validation Module

Usage

data_filterout_ui(id)

data_filterout_server(id, data_r = reactive(NULL))

data_validation_ui(id)

data_validation_server(id, data_r = reactive(NULL))

Arguments

id

Module's ID.

data_r

A reactive function returning a data.frame.

Value

  • UI: HTML tags that can be included in the UI part of the application.

  • Server: a shiny::reactive() function returning a data.frame.

  • UI: HTML tags that can be included in the UI part of the application.

  • Server: a shiny::reactive() function returning a data.frame.