Variable selection Module
Usage
data_variable_ui(id)
data_variable_server(id, data_r = reactive(NULL))Value
UI: HTML tags that can be included in the UI part of the application.
Server: a
shiny::reactive()function returning alist.
Variable selection Module
data_variable_ui(id)
data_variable_server(id, data_r = reactive(NULL))UI: HTML tags that can be included in the UI part of the application.
Server: a shiny::reactive() function returning a list.