Extract from a sql database an exact match on a given field
Value
A list of two elements, one with the extract if any, two with the names with id not NA when matched
Author
Gilles Dauby, gilles.dauby@ird.fr
Extract from a sql database an exact match on a given field
A list of two elements, one with the extract if any, two with the names with id not NA when matched
Gilles Dauby, gilles.dauby@ird.fr