Skip to contents

Extract all records of all taxa identified to species level into a dranw polygon from the rainbio database

Usage

query_rb_poly(poly, only_checked_georef = TRUE)

Arguments

poly

An sf object, typically a polygon obtained with mapedit::drawFeatures().

only_checked_georef

logical, whether filtering out occurrences with non validated georeferencing.

Value

A list with the sf of the rainbio database extracted, the polygon used to extract, a tibble with idtax

Author

Gilles Dauby, gilles.dauby@ird.fr

Examples

if (FALSE) { # \dontrun{
poly <- mapedit::drawFeatures()
query_rb_poly(poly)
} # }