Skip to contents

Extract from the Rainbio database of all records from a species list

Usage

query_rb_taxa(species = NULL, idtax = NULL, only_checked_georef = TRUE)

Arguments

species

Names of species to search for.

idtax

idtax.

only_checked_georef

logical, whether filtering out occurrences with non validated georeferencing.

Value

A list with the sf of the Rainbio database extracted, the polygon used to extract, a tibble with idtax

Author

Gilles Dauby, gilles.dauby@ird.fr

Examples

if (FALSE) { # \dontrun{
query_rb_taxa(species = c("diospyros iturensis", "anthonotha macrophylla"))
} # }