Data filtering out Module
Source:R/module-data-filterout.R, R/module-data-validation.R
module-data-validation.RdData filtering out Module
Data Validation Module
Value
UI: HTML tags that can be included in the UI part of the application.
Server: a
shiny::reactive()function returning adata.frame.
UI: HTML tags that can be included in the UI part of the application.
Server: a
shiny::reactive()function returning adata.frame.