Extract all records of all taxa identified to species level into a dranw polygon from the rainbio database
Arguments
- poly
An
sfobject, typically a polygon obtained withmapedit::drawFeatures().- only_checked_georef
logical, whether filtering out occurrences with non validated georeferencing.
Value
A list with the sf of the rainbio database extracted, the polygon used to extract, a tibble with idtax
Author
Gilles Dauby, gilles.dauby@ird.fr
Examples
if (FALSE) { # \dontrun{
poly <- mapedit::drawFeatures()
query_rb_poly(poly)
} # }