Extract from the Rainbio database of all records from a species list
Value
A list with the sf of the Rainbio database extracted, the polygon used to extract, a tibble with idtax
Author
Gilles Dauby, gilles.dauby@ird.fr
Examples
if (FALSE) { # \dontrun{
query_rb_taxa(species = c("diospyros iturensis", "anthonotha macrophylla"))
} # }